package com.aitrainer.api.controller

import com.aitrainer.api.model.Exercises
import com.aitrainer.api.repository.ExercisesRepository
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class ExerciseController(private val exercisesRepository: ExercisesRepository) {

    @GetMapping("/exercises/{id}")
    fun getExerciseById(@PathVariable(value = "id") exerciseId: Long): ResponseEntity<Exercises> {
        return exercisesRepository.findById(exerciseId).map { exercise ->
            ResponseEntity.ok(exercise)
        }.orElse(ResponseEntity.notFound().build())
    }

    @GetMapping("/exercises/customer/{id}")
    fun getAllExersicesByCustomerId(@PathVariable( value = "id" ) customerId: Long? ): List<Exercises> =
            exercisesRepository.getAllByCustomerId(customerId)

    @PostMapping("/exercises")
    fun createNewExercise(@Valid @RequestBody exercise: Exercises): Exercises {
        return exercisesRepository.save(exercise)
    }

    @PutMapping("/exercises/{id}")
    fun updateExerciseById(@PathVariable(value = "id") exerciseId: Long,
                           @Valid @RequestBody newExercises: Exercises): ResponseEntity<Exercises> {
        return exercisesRepository.findById(exerciseId).map { existingExercises ->
            val updatedExercises: Exercises = existingExercises.copy(
                    exerciseTypeId = newExercises.exerciseTypeId,
                    customerId = newExercises.customerId,
                    dateAdd = newExercises.dateAdd,
                    quantity = newExercises.quantity,
                    restTime = newExercises.restTime
            )
            ResponseEntity.ok().body(exercisesRepository.save(updatedExercises))
        }.orElse(ResponseEntity.notFound().build())
    }
}